import React, { Component } from 'react';
import './App.css';
import { QueryBuilderComponent } from '@syncfusion/ej2-react-querybuilder';
import { Query, DataManager, ODataV4Adaptor } from '@syncfusion/ej2-data';

import { GridComponent, Page, Inject, ColumnsDirective, ColumnDirective } from '@syncfusion/ej2-react-grids';
import { isNullOrUndefined } from '@syncfusion/ej2-base';

class App extends Component {
  constructor() {
    super(...arguments);
    this.datamanager = new DataManager({
       adaptor: new ODataV4Adaptor,
       url: 'https://services.odata.org/V4/Northwind/Northwind.svc/Orders/'
    });
   
    this.columnData = [
        { field: 'OrderID', label: 'Order ID', type: 'number' },
        { field: 'CustomerID', label: 'Cutomer ID', type: 'string' },
        { field: 'EmployeeID', label: 'Employee ID', type: 'string' },
        { field: 'Freight', label: 'Freight', type: 'string' },
        { field: 'ShipCountry', label: 'Ship Country', type: 'string' }
    ];
    this.importRules = {
        'condition': 'or',
        'rules': [{
                'label': 'OrderID',
                'field': 'OrderID',
                'type': 'number',
                'operator': 'equal',
                'value':  10248
            }]
    };
}
updateRule(args) {
    let predicate = this.qbObj.getPredicate(args.rule);
    if (isNullOrUndefined(predicate)) {
        this.gridObj.query = new Query().select(['OrderID','CustomerID', 'EmployeeID', 'Freight', 'ShipCountry' ]);
    }
    else {
        this.gridObj.query = new Query().select(['OrderID','CustomerID', 'EmployeeID', 'Freight', 'ShipCountry' ]).where(predicate);
    }
    this.gridObj.refresh();
}
onGridCreated() {
    this.updateRule({ rule: this.qbObj.getValidRules(this.qbObj.rule) });
}
  render() {
    return (<div className='control-pane'>
                <div className='control-section qb-section'>
                    <div className='row'>
                        <div className='col-lg-12 control-section qb-section'>
                            { <QueryBuilderComponent width='100%' dataSource={this.datamanager} columns={this.columnData} rule={this.importRules} ruleChange={this.updateRule.bind(this)} ref={(scope) => { this.qbObj = scope; }}>
                            </QueryBuilderComponent> }
                        </div>
                        <div className='col-lg-12 control-section qb-section'>
                            <div className='content-wrapper'>
                                <GridComponent allowPaging={true} dataSource={this.datamanager} width='100%' ref={(scope) => { this.gridObj = scope; }} created={this.onGridCreated.bind(this)}>
                                    <ColumnsDirective>
                                    <ColumnDirective field='OrderID' headerText='Order ID' width='120' textAlign='Right'></ColumnDirective>
                            <ColumnDirective field='CustomerID' headerText='Customer ID' width='160'></ColumnDirective>
                            <ColumnDirective field='EmployeeID' headerText='Employee ID' width='120' textAlign='Right' />
                            <ColumnDirective field='Freight' headerText='Freight' width='150' format='C2' textAlign='Right' />
                            <ColumnDirective field='ShipCountry' headerText='Ship Country' width='150'></ColumnDirective>
                                    </ColumnsDirective>
                                    <Inject services={[Page]}/>
                                </GridComponent>
                            </div>
                        </div>
                    </div>
                </div>
            </div>);
  }
}

export default App;
